yakumo.keystone.v3.credential

Package yakumo :: Package keystone :: Package v3 :: Module credential |
[hide private]
[frames] | no frames]

# Module credential

source code

Resource class and its manager for credentials in Identity V3 API

Classes | [hide private]
| Resource resource class for credentials on Identity V3 API
| Manager manager class for credentials on Identity V3 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.keystone.v3``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('type', 'type', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('blob', 'blob', <yakumo.mapper.JSONClass object at 0x7f133076fad0>),
       ('user',
        'user_id',
        <yakumo.mapper.Resource object at 0x7f132fc277d0>),
       ('project',
        'project_id',
      ...